@@ -626,7 +626,11 @@ class ControlConnection implements Connection.Owner {
       broadcastRpcAddress = new InetSocketAddress(nativeAddress, nativePort);
     } else if (row.getColumnDefinitions().contains("rpc_address")) {
       InetAddress rpcAddress = row.getInet("rpc_address");
-      broadcastRpcAddress = new InetSocketAddress(rpcAddress, cluster.connectionFactory.getPort());
+      int nativePort = cluster.connectionFactory.getPort();
+      if (row.getColumnDefinitions().contains("rpc_port")) {
+        nativePort = row.getInt("rpc_port");
+      }
+      broadcastRpcAddress = new InetSocketAddress(rpcAddress, nativePort);
     }
     // Before CASSANDRA-9436, system.local doesn't have rpc_address, so this might be null. It's not
     // a big deal because we only use this for server events, and the control node doesn't receive
@@ -854,8 +858,11 @@ class ControlConnection implements Connection.Owner {
         broadcastRpcAddress = new InetSocketAddress(nativeAddress, nativePort);
       } else {
         InetAddress rpcAddress = row.getInet("rpc_address");
-        broadcastRpcAddress =
-            new InetSocketAddress(rpcAddress, cluster.connectionFactory.getPort());
+        int nativePort = cluster.connectionFactory.getPort();
+        if (row.getColumnDefinitions().contains("rpc_port")) {
+          nativePort = row.getInt("rpc_port");
+        }
+        broadcastRpcAddress = new InetSocketAddress(rpcAddress, nativePort);
       }
       broadcastRpcAddresses.add(broadcastRpcAddress);
 
